@@ -295,7 +295,7 @@ class SamplerWindow(Window):
 
             self.updateFeatureList(self._currentList)
 
-            self.setCaption((f.getName() + ' }> ' if f is not None else '')
+            self.setCaption((f.getName() + ': ' if f is not None else '')
                     + self._TITLE)
 
     # SamplerWindow helpers
