@@ -13,12 +13,13 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Note: This is a modified file from Vaadin. For further information on
+#       Vaadin please visit http://www.vaadin.com.
 
 """Defines a class representing a selection of items the user has selected
 in a UI."""
 
-from collections import Iterable
-
 from muntjac.ui.abstract_field import AbstractField
 from muntjac.terminal.resource import IResource
 from muntjac.terminal.key_mapper import KeyMapper
@@ -56,7 +57,7 @@ class AbstractSelect(AbstractField, container.IContainer, container.IViewer,
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.0.0
+    @version: 1.0.1
     """
 
     #: IItem caption mode: IItem's ID's C{String} representation
@@ -458,7 +459,7 @@ class AbstractSelect(AbstractField, container.IContainer, container.IViewer,
                 if newValue is None:
                     super(AbstractSelect, self).setValue(set(),
                             repaintIsNotNeeded)
-                elif isinstance(newValue, Iterable):
+                elif hasattr(newValue, '__iter__'):
                     super(AbstractSelect, self).setValue(set(newValue),
                             repaintIsNotNeeded)
 
