@@ -13,6 +13,9 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# Note: This is a modified file from Vaadin. For further information on
+#       Vaadin please visit http://www.vaadin.com.
 
 import os
 import sys
@@ -20,7 +23,7 @@ import locale
 
 import paste.webkit
 
-from babel import Locale
+from babel.core import Locale, UnknownLocaleError
 
 
 # Copied from paste.webkit.wsgiapp to avoid paste.deploy dependency.
@@ -64,7 +67,10 @@ def defaultLocale():
     if lang is not None:
         return Locale.parse(lang)
     else:
-        return Locale.default()
+        try:
+            return Locale.default()
+        except UnknownLocaleError:
+            return Locale('en', 'US')
 
 
 class EventObject(object):
